wrapplotly is a python wrapper for common plotly graph types.

[API Documentation](https://www.jill.codes/wrapplotly)

- bar charts
- histograms
- scatterplots
- box plots
- line charts
- word clouds

wrapplotly allows creation of both single plots and subplot-type figures